package org.ugasp.connector.manager;


import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;

import org.ugasp.core.Platform;
import org.ugasp.service.external.player.PlayerConnector;

/**
 *  This is the interface that should implement a class managing the data transmission request
 *  of a client.
 * 
 * @author Gabriel Adgeg (gabriel.adgeg@telecom-sudparis.eu)
 */
public interface DataTransmissionRequestManager {
	
	/**
	 * Treat the data transmission request sent by a client.
	 * Treatment of the request includes the suitable management for the data sent by the client,
	 * and possibly to transmit data to the client on the response of its request.
	 * 
	 * @throws IOException
	 */
	public void treatClientRequest() throws IOException;
	
	/**
	 * Get the DataInputStream matching with the client request.
	 * 
	 * @return 	the DataInputStream
	 */
	public DataInputStream getRequestInputStream();
	
	
	/**
	 * Get the DataOutputStream matching with the platform response.
	 * 
	 * @return 	the DataOutputStream
	 */
	public DataOutputStream getResponseOutputStream();
	
	/**
	 * Get the PlayerConnector needed to:
	 * <ul>
	 * <li>treat data received from a player</li>
	 * <li>transmit data designed to this player</li>
	 * </ul>
	 * @return 	the PlayerConnector
	 */
	public PlayerConnector getPlayerConnector();
	
	
	/**
	 * Get the platform. Needed to retrieve an ApplicationInstance from an actorSessionID.
	 * 
	 * @return 	the uGASP Platform
	 */
	public Platform getPlatform();
}
