/***
 * uGASP: an OSGi middleware dedicated to ubiquitous multiplayer gaming.
 * Copyright (C) 2008 CNAM/INT
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contact: gasp-team@objectweb.org
 *
 * Author: Romain Pellerin
 */
package org.ugasp.core.utils;

import java.util.Map;
import java.util.Vector;

/** 
 * This class is used to construct an object representing the current AIs State.
 * @author PELLERIN Romain (pellerin@cnam.fr) - MEGA Project 
 */
public class ApplicationInstanceInfos {
	
	private int appInstanceID;
	private int nbP;
	private int min;
	private int max;
	private Vector<Player> pList;
	private Map<String,String> optionalInfos;

	private ApplicationInstanceInfos(int applicationInstanceID, int minOfActors, int maxOfActors, int nbPlayers, Vector<Player> playerList, Map<String,String> optionalInfos){
		appInstanceID= applicationInstanceID;
		nbP= nbPlayers;
		min = minOfActors;
		max = maxOfActors;
		pList = new Vector<Player>(playerList);
		this.optionalInfos = optionalInfos;
	}
	
	public static ApplicationInstanceInfos getInstance (int applicationInstanceID, int minOfActors, int maxOfActors, int nbPlayers, Vector<Player> playerList, Map<String,String> optionalInfos){
		return new ApplicationInstanceInfos(applicationInstanceID, minOfActors, maxOfActors, nbPlayers, playerList, optionalInfos);
	}
	
	public int getApplicationInstanceID(){return appInstanceID;}
	
	public int getNbPlayers(){return nbP;}

    public int getMinActors() {
        return min;
    }

    public int getMaxActors() {
        return max;
    }
    
    public Vector<Player> getPlayerList(){
    	return pList;
    }
    
    public Map<String, String> getOptionalInfos() {
		return optionalInfos;
	}

	public static class Player{
    	
    	private String 	pseudoName;
    	private int		actorId;
    	
    	private Player(String pseudoName, int actorId){
    		this.pseudoName = pseudoName;
    		this.actorId 	= actorId;
    	}
    	
    	public static Player getInstance(String pseudoName, int actorId){
    		return new Player(pseudoName, actorId);
    	}

		public String getPseudoName() {
			return pseudoName;
		}

		public int getActorId() {
			return actorId;
		}
    	
    }
}
