/***
 * uGASP: an OSGi middleware dedicated to ubiquitous multiplayer gaming.
 * Copyright (C) 2008 CNAM/INT
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contact: gasp-team@objectweb.org
 *
 * Author: Romain Pellerin
 */
package org.ugasp.eventmodel.event.impl;

import org.ugasp.eventmodel.event.RMAIEvent;

/**
 * RMAIEvent is an event generated by the actor in game to invoke a remote method asynchronously
 * either on (a) uGASP client(s) and/or on uGASP Server
 * 
 * @author Adgeg Gabriel (gabriel.adgeg@telecom-sudparis.eu) - PlayOnline
 */
public class RMAIEventImpl extends EventImpl implements RMAIEvent{
	
	private short recipientActorSessionID;
	private String invokedMethodXMLSerialized;

	public RMAIEventImpl(short senderActorSessionID, short recipientActorSessionID, String invokedMethodXMLSerialized){
		this.aSID = senderActorSessionID;
		this.recipientActorSessionID = recipientActorSessionID;
		this.invokedMethodXMLSerialized = invokedMethodXMLSerialized;
		code = EventsType.RMAI_EVENT_TYPE;
	}
	
	/**
	 * Return the actorSessionID of the client on which method should be invoked.
	 * 
	 * @return 	 actorSessionID > 0 if the method should be invoked on a uGASP client
	 * 			 0 	if the method should be invoked on uGASP Server
	 * 			-1	if the method should be invoked on every uGASP clients
	 *	 		-2	if the method should be invoked on every uGASP clients and on uGASP server
	 */
	public short getRecipientActorSessionID(){
		return recipientActorSessionID;
	}
	
	
	/**
	 * Return a string containing the XML serialisation of the method which should be invoked remotly.
	 * The XML serialisation contains :
	 * - the method name
	 * - method parameters types 
	 * - method parameters values 
	 * 
	 * @return the String representation of the remote method invoked.
	 */
	public String getInvokedMethodXMLSerialized(){
		return invokedMethodXMLSerialized;
	}

}
