package org.ugasp.logging;

/**
 * This interface provides several level of logs used within ugasp,
 * from the lowest, Logger.TRACE, to the highest, Logger.FATAL.
 * In addition, it provides two logs methods:
 * <ul>
 * <li>one used when the log message is set by the developer</li>
 * <li>another one used when the developer wants to insert both
 * its message and the stack trace of an exception caught in the log</li>
 * </ul>
 */
public interface Logger {

	public static final byte FATAL 	= 6;
	public static final byte ERROR 	= 5;
	public static final byte WARN 	= 4;
	public static final byte INFO 	= 3;
	public static final byte DEBUG 	= 2;
	public static final byte TRACE 	= 1;
	
	/**
	 * Log a message for a special class with an associated level.
	 * 
	 * @param logLevel	the level of the log, that must be chosen between TRACE, DEBUG, INFO, WAR, ERROR or FATAL
	 * @param clazz		the class where the log is located
	 * @param log		the log message
	 */
	public void log(byte logLevel, Class<?> clazz, String log);	
	
	
	/**
	 * Log a message for a special class with an associated level. 
	 * In addition to the other log method, this one has a Throwable parameter. The stack trace of this Throwable
	 * should be provided by the log.
	 * Note that this method should be use for a level of Logger superior or equals to 
	 * 
	 * @param logLevel	the level of the log, that should be chosen between WARN, ERROR or FATAL
	 * @param clazz		the class where the log is located
	 * @param log		the log message
	 * @param t			the Throwable whose stack trace should be logged
	 */
	public void log(byte logLevel, Class<?> clazz, String log, Throwable t);
}
