package org.ugasp.protocol.rmai;

/**
 * Implementations of this interface allows :
 * - serialization of methods signatures as Strings values of XML representations 
 * - creation of InvokedMethod objects from those Strings. 
 */
public interface RMAIUtils{
	
	/**
	 * Serialize in an XML way a String value of a method name and an Object[] representing 
	 * parameters into a String.
	 * 
	 * @param methodName	name of the method to invoke
	 * @param params		parameters of the method to invoke
	 * @return				the String serialization of method name and parameters
	 * @throws Exception if a RMAISerializable object is attempted to be serialized while it is not located in the suitable package.
	 * @see RMAISerializable  
	 */
	public String methodInvocation(String methodName, Object[] params)throws Exception;	
	
	
	/**
	 * Set the folder where RMAISerializable objects are located.
	 * All RMAISerializable objects MUST be located with in the same folder.
	 * 
	 * @param folderName
	 */
	public void setRMAISerializableObjectsFolder(String folderName);
	
	/**
	 * Get an instance of InvokedMethod from a xml serialization stored in a String.
	 * This method parse the string to retrieve the method name as a String 
	 * and the parameters as an Object[].
	 * Method name and parameters are then used to return the matching InvokeMethod.
	 * 
	 * @param invokedMethodXMLSerialized	the String representing the method invoked, serialized xml way
	 * @return InvokedMethod				an InvokedMethod containing method name and parameters retrieved from the string.
	 * @throws	ClassNotFoundException 		when trying to deserialize an object which class that could be found
	 * @throws	InstantiationException 		when trying to deserialize an object which has no nullary constructor 	
	 * @throws	IllegalAccessException 		when trying to deserialize an object which nullary constructor is not public
	 */
	public InvokedMethod readMethodInvocation(String invokedMethodXMLSerialized)throws 	ClassNotFoundException,
																						InstantiationException,
																						IllegalAccessException;	
}
