/***
 * uGASP: an OSGi middleware dedicated to ubiquitous multiplayer gaming.
 * Copyright (C) 2008 CNAM/INT
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * 
 * Contact: gasp-team@objectweb.org
 *
 * Author: Romain Pellerin
 */
package org.ugasp.impl.gamelogic;

import java.util.Hashtable;

import org.apache.felix.ipojo.ComponentInstance;
import org.apache.felix.ipojo.Factory;
import org.apache.felix.ipojo.InstanceManager;
import org.apache.felix.ipojo.architecture.PropertyDescription;
import org.osgi.framework.BundleContext;

import org.ugasp.gamelogic.GameLogicsFactory;
import org.ugasp.logging.Logger;

public class GameLogicsFactoryImpl implements GameLogicsFactory{
	
	// iPojo injection fields
	private Factory[] gameLogics;
	private Logger logger;
	private BundleContext context;
	
	public GameLogicsFactoryImpl(BundleContext bc) {
		context = bc;
		logger.log(Logger.INFO,this.getClass(),"Game Logics Factory instantiated");
	}
	
	public InstanceManager newGameLogicInstance(int appID){
		try {
			Factory gameLogicsFactory = getGameLogicsFactory(appID);
			if (gameLogicsFactory != null){
					ComponentInstance componentInstance = gameLogicsFactory.createComponentInstance(null);
					return (InstanceManager) componentInstance;					
			}			
		} catch (Throwable t){
			logger.log(Logger.WARN,this.getClass(),"Game Logics Factory cannot instantiate any game logic");
		} 
		return null;
	}
	
	
	private Factory getGameLogicsFactory(int appID){
		Factory gameLogic = null;
		for (int i=0; i<gameLogics.length;i++){
			gameLogic = gameLogics[i];
			PropertyDescription[] properties = gameLogic.getComponentDescription().getProperties();	
			PropertyDescription property = null;
			for (int j=0; j<properties.length;j++){
				property = properties[j];
				if (property.getName().equals("appID") && property.getValue().equals(""+appID)){
					return gameLogic;	
				}	
			}
		}
		return null;
	}


	public Hashtable getApplicationProperties(int appID) {
		Hashtable appInfos = new Hashtable();
		Factory gameLogic = null;
		for (int i=0; i<gameLogics.length;i++){
			gameLogic = gameLogics[i];
			PropertyDescription[] properties = gameLogic.getComponentDescription().getProperties();	
			PropertyDescription property = null;
			for (int j=0; j<properties.length;j++){
				property = properties[j];
				if (property.getName().equals("appID")){
					appInfos.put(property.getName(), property.getValue());
				}
				else if (property.getName().equals("timeout")){
					appInfos.put(property.getName(), property.getValue());
				}
				else if (property.getName().equals("model")){
					appInfos.put(property.getName(), property.getValue());
				}
			}
			
			Object value = appInfos.get("appID");
			
			if (value != null){
				if (((String) value).equals(""+appID)) return appInfos;
				else appInfos.clear();
			}		
		}
		
		return appInfos;
	}
}
